Class: Google::Apis::KmsinventoryV1::GoogleCloudKmsV1CryptoKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/kmsinventory_v1/classes.rb,
lib/google/apis/kmsinventory_v1/representations.rb,
lib/google/apis/kmsinventory_v1/representations.rb

Overview

A CryptoKey represents a logical key that can be used for cryptographic operations. A CryptoKey is made up of zero or more versions, which represent the actual key material used in cryptographic operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudKmsV1CryptoKey

Returns a new instance of GoogleCloudKmsV1CryptoKey.



346
347
348
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this CryptoKey was created. Corresponds to the JSON property createTime

Returns:

  • (String)


257
258
259
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 257

def create_time
  @create_time
end

#crypto_key_backendString

Immutable. The resource name of the backend environment where the key material for all CryptoKeyVersions associated with this CryptoKey reside and where all related cryptographic operations are performed. Only applicable if CryptoKeyVersions have a ProtectionLevel of EXTERNAL_VPC, with the resource name in the format projects/*/locations/*/ekmConnections/*. Only applicable if CryptoKeyVersions have a ProtectionLevel of HSM_SINGLE_TENANT, with the resource name in the format projects/*/locations/*/singleTenantHsmInstances/* . Note, this list is non-exhaustive and may apply to additional ProtectionLevels in the future. Corresponds to the JSON property cryptoKeyBackend

Returns:

  • (String)


270
271
272
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 270

def crypto_key_backend
  @crypto_key_backend
end

#destroy_scheduled_durationString

Immutable. The period of time that versions of this key spend in the DESTROY_SCHEDULED state before transitioning to DESTROYED. If not specified at creation time, the default duration is 30 days. Corresponds to the JSON property destroyScheduledDuration

Returns:

  • (String)


277
278
279
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 277

def destroy_scheduled_duration
  @destroy_scheduled_duration
end

#import_onlyBoolean Also known as: import_only?

Immutable. Whether this key may contain imported versions only. Corresponds to the JSON property importOnly

Returns:

  • (Boolean)


282
283
284
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 282

def import_only
  @import_only
end

#key_access_justifications_policyGoogle::Apis::KmsinventoryV1::GoogleCloudKmsV1KeyAccessJustificationsPolicy

A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey or KeyAccessJustificationsPolicyConfig (the default Key Access Justifications policy). Corresponds to the JSON property keyAccessJustificationsPolicy



291
292
293
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 291

def key_access_justifications_policy
  @key_access_justifications_policy
end

#labelsHash<String,String>

Labels with user-defined metadata. For more information, see Labeling Keys. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


297
298
299
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 297

def labels
  @labels
end

#nameString

Output only. The resource name for this CryptoKey in the format projects/*/ locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property name

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 303

def name
  @name
end

#next_rotation_timeString

At next_rotation_time, the Key Management Service will automatically: 1. Create a new version of this CryptoKey. 2. Mark the new version as primary. Key rotations performed manually via CreateCryptoKeyVersion and UpdateCryptoKeyPrimaryVersion do not affect next_rotation_time. Keys with purpose ENCRYPT_DECRYPT support automatic rotation. For other keys, this field must be omitted. Corresponds to the JSON property nextRotationTime

Returns:

  • (String)


313
314
315
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 313

def next_rotation_time
  @next_rotation_time
end

#primaryGoogle::Apis::KmsinventoryV1::GoogleCloudKmsV1CryptoKeyVersion

A CryptoKeyVersion represents an individual cryptographic key, and the associated key material. An ENABLED version can be used for cryptographic operations. For security reasons, the raw cryptographic key material represented by a CryptoKeyVersion can never be viewed or exported. It can only be used to encrypt, decrypt, or sign data when an authorized user or application invokes Cloud KMS. Corresponds to the JSON property primary



323
324
325
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 323

def primary
  @primary
end

#purposeString

Immutable. The immutable purpose of this CryptoKey. Corresponds to the JSON property purpose

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 328

def purpose
  @purpose
end

#rotation_periodString

next_rotation_time will be advanced by this period when the service automatically rotates a key. Must be at least 24 hours and at most 876,000 hours. If rotation_period is set, next_rotation_time must also be set. Keys with purpose ENCRYPT_DECRYPT support automatic rotation. For other keys, this field must be omitted. Corresponds to the JSON property rotationPeriod

Returns:

  • (String)


337
338
339
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 337

def rotation_period
  @rotation_period
end

#version_templateGoogle::Apis::KmsinventoryV1::GoogleCloudKmsV1CryptoKeyVersionTemplate

A CryptoKeyVersionTemplate specifies the properties to use when creating a new CryptoKeyVersion, either manually with CreateCryptoKeyVersion or automatically as a result of auto-rotation. Corresponds to the JSON property versionTemplate



344
345
346
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 344

def version_template
  @version_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 351

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_backend = args[:crypto_key_backend] if args.key?(:crypto_key_backend)
  @destroy_scheduled_duration = args[:destroy_scheduled_duration] if args.key?(:destroy_scheduled_duration)
  @import_only = args[:import_only] if args.key?(:import_only)
  @key_access_justifications_policy = args[:key_access_justifications_policy] if args.key?(:key_access_justifications_policy)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @next_rotation_time = args[:next_rotation_time] if args.key?(:next_rotation_time)
  @primary = args[:primary] if args.key?(:primary)
  @purpose = args[:purpose] if args.key?(:purpose)
  @rotation_period = args[:rotation_period] if args.key?(:rotation_period)
  @version_template = args[:version_template] if args.key?(:version_template)
end