Class: Google::Apis::KmsinventoryV1::GoogleCloudKmsV1CryptoKeyVersionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/kmsinventory_v1/classes.rb,
lib/google/apis/kmsinventory_v1/representations.rb,
lib/google/apis/kmsinventory_v1/representations.rb

Overview

A CryptoKeyVersionTemplate specifies the properties to use when creating a new CryptoKeyVersion, either manually with CreateCryptoKeyVersion or automatically as a result of auto-rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudKmsV1CryptoKeyVersionTemplate

Returns a new instance of GoogleCloudKmsV1CryptoKeyVersionTemplate.



536
537
538
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Required. Algorithm to use when creating a CryptoKeyVersion based on this template. For backwards compatibility, GOOGLE_SYMMETRIC_ENCRYPTION is implied if both this field is omitted and CryptoKey.purpose is ENCRYPT_DECRYPT. Corresponds to the JSON property algorithm

Returns:

  • (String)


528
529
530
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 528

def algorithm
  @algorithm
end

#protection_levelString

ProtectionLevel to use when creating a CryptoKeyVersion based on this template. Immutable. Defaults to SOFTWARE. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


534
535
536
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 534

def protection_level
  @protection_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



541
542
543
544
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 541

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
end