Class: Google::Apis::KmsinventoryV1::GoogleCloudKmsInventoryV1Warning
- Inherits:
-
Object
- Object
- Google::Apis::KmsinventoryV1::GoogleCloudKmsInventoryV1Warning
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/kmsinventory_v1/classes.rb,
lib/google/apis/kmsinventory_v1/representations.rb,
lib/google/apis/kmsinventory_v1/representations.rb
Overview
A warning message that indicates potential problems with the response data.
Instance Attribute Summary collapse
-
#display_message ⇒ String
The literal message providing context and details about the warnings.
-
#warning_code ⇒ String
The specific warning code for the displayed message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudKmsInventoryV1Warning
constructor
A new instance of GoogleCloudKmsInventoryV1Warning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudKmsInventoryV1Warning
Returns a new instance of GoogleCloudKmsInventoryV1Warning.
237 238 239 |
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_message ⇒ String
The literal message providing context and details about the warnings.
Corresponds to the JSON property displayMessage
230 231 232 |
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 230 def @display_message end |
#warning_code ⇒ String
The specific warning code for the displayed message.
Corresponds to the JSON property warningCode
235 236 237 |
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 235 def warning_code @warning_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
242 243 244 245 |
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 242 def update!(**args) @display_message = args[:display_message] if args.key?(:display_message) @warning_code = args[:warning_code] if args.key?(:warning_code) end |