Class: Google::Apis::KmsinventoryV1::GoogleCloudKmsV1ExternalProtectionLevelOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/kmsinventory_v1/classes.rb,
lib/google/apis/kmsinventory_v1/representations.rb,
lib/google/apis/kmsinventory_v1/representations.rb

Overview

ExternalProtectionLevelOptions stores a group of additional fields for configuring a CryptoKeyVersion that are specific to the EXTERNAL protection level and EXTERNAL_VPC protection levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudKmsV1ExternalProtectionLevelOptions

Returns a new instance of GoogleCloudKmsV1ExternalProtectionLevelOptions.



574
575
576
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ekm_connection_backend_overrideString

Optional. The resource name of the backend environment where the key material of CryptoKeyVersions is associated with. Setting this field overrides the CryptoKeyBackend. This field may be set when CryptoKeyVersions is set to EXTERNAL_VPC. Format: projects/*/locations/*/ekmConnections/*. Corresponds to the JSON property ekmConnectionBackendOverride

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 559

def ekm_connection_backend_override
  @ekm_connection_backend_override
end

#ekm_connection_key_pathString

Optional. The path to the external key material on the EKM when using EkmConnection e.g., "v0/my/key". Set this field instead of external_key_uri when using an EkmConnection. Corresponds to the JSON property ekmConnectionKeyPath

Returns:

  • (String)


566
567
568
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 566

def ekm_connection_key_path
  @ekm_connection_key_path
end

#external_key_uriString

Optional. The URI for an external resource that this CryptoKeyVersion represents. Corresponds to the JSON property externalKeyUri

Returns:

  • (String)


572
573
574
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 572

def external_key_uri
  @external_key_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



579
580
581
582
583
# File 'lib/google/apis/kmsinventory_v1/classes.rb', line 579

def update!(**args)
  @ekm_connection_backend_override = args[:ekm_connection_backend_override] if args.key?(:ekm_connection_backend_override)
  @ekm_connection_key_path = args[:ekm_connection_key_path] if args.key?(:ekm_connection_key_path)
  @external_key_uri = args[:external_key_uri] if args.key?(:external_key_uri)
end